==> api_compose-0.0.11.tar.gz: api_compose-0.0.11/src/api_compose/services/composition_service/processors/schema_validators/json_schema_validator.py <==
__all__ = ["JsonSchemaValidator"]

import traceback
from abc import ABC

import jsonschema
from jsonschema.exceptions import ValidationError

from api_compose.core.logging import get_logger
from api_compose.services.common.registry.processor_registry import ProcessorRegistry, ProcessorType, \
    ProcessorCategory
from api_compose.services.composition_service.events.schema_validator import SchemaValidatorEvent
from api_compose.services.composition_service.models.schema_validatiors.schema_validators import \
    JsonSchemaValidatorModel
from api_compose.services.composition_service.processors.schema_validators.base_schema_validator import \
    BaseSchemaValidator

logger = get_logger(__name__)


@ProcessorRegistry.set(

    processor_category=ProcessorCategory.SchemaValidator,
    models=[
        JsonSchemaValidatorModel(id='OK', schema_id='200'),
    ]
)
class JsonSchemaValidator(BaseSchemaValidator, ABC):
    """
    validate

    """

    def __init__(
            self,
            *args,
            **kwargs,
    ):
        super().__init__(*args, **kwargs)

    def validate(self):
        super().validate()
        if self.is_setup_success:
            self.schema_validator_model.actual = self.actual

            try:
                jsonschema.validate(
                    self.actual,
                    self.expected_schema
                )
            except Exception as e:
                logger.error(traceback.format_exc(), SchemaValidatorEvent())
                self.schema_validator_model.exec = traceback.format_exc()
                self.schema_validator_model.is_valid = False
            else:
                logger.debug(f"Schema is valid - {self.actual=}", SchemaValidatorEvent())
                self.schema_validator_model.is_valid = True

==> api_compose-0.0.12.tar.gz: api_compose-0.0.12/src/api_compose/services/composition_service/processors/schema_validators/json_schema_validator.py <==
__all__ = ["JsonSchemaValidator"]

import traceback
from abc import ABC

import jsonschema

from api_compose.core.logging import get_logger
from api_compose.services.common.registry.processor_registry import ProcessorRegistry, ProcessorCategory
from api_compose.services.composition_service.events.schema_validator import SchemaValidatorEvent
from api_compose.services.composition_service.models.schema_validatiors.schema_validators import \
    JsonSchemaValidatorModel
from api_compose.services.composition_service.processors.schema_validators.base_schema_validator import \
    BaseSchemaValidator

logger = get_logger(__name__)


@ProcessorRegistry.set(

    processor_category=ProcessorCategory.SchemaValidator,
    models=[
        JsonSchemaValidatorModel(id='OK', schema_id='200'),
    ]
)
class JsonSchemaValidator(BaseSchemaValidator, ABC):
    """
    validate

    """

    def __init__(
            self,
            *args,
            **kwargs,
    ):
        super().__init__(*args, **kwargs)

    def validate(self):
        super().validate()
        if self.is_setup_success:
            self.schema_validator_model.actual = self.actual

            try:
                jsonschema.validate(
                    self.actual,
                    self.expected_schema
                )
            except Exception as e:
                logger.error(traceback.format_exc(), SchemaValidatorEvent())
                self.schema_validator_model.exec = traceback.format_exc()
                self.schema_validator_model.is_valid = False
            else:
                logger.debug(f"Schema is valid - {self.actual=}", SchemaValidatorEvent())
                self.schema_validator_model.is_valid = True
